import axios from 'axios';
import moment from 'moment';
import { orderDetail, orderEdit, ticketRefund } from '@/api/order.js';

export default {
    name: 'OrderDetail',

    data() {
        return {
            // 加载菊花
            loading: false,
            // 订单信息
            orderData: [],
            // 乘客信息
            passengerData: [],
            // 备注
            strRemark: '',
            // 预览图片地址
            imageUrl: '',
            // 退票数据
            refundData: { orderId: this.$route.query.orderId, recedeType: '1' },
            // 改签数据
            rebookData: { passengerList: [] },
            // 乘客列表中选中的要退票或改签的乘客列表
            choosedPassengeList: [],
            // 日历配置项
            pickerOptions: {
                disabledDate(time) {
                    return time.getTime() < moment().subtract(1, "days");
                }
            },
        };
    },

    computed: {
        titleType() {
            let type = this.$route.query.type;
            let typeList = [ '订单', '退票', '改签', '编辑', '支付' ];
            return typeList[parseInt(this.$route.query.type) - 1];
        }
    },

    mounted() {
        // 获取订单详情信息
        this.getOrderDetail(this.$route.query.orderId);
    },

    methods: {
        /**
         * 获取订单详情信息
         */
        getOrderDetail(orderId) {
            let reqData = { orderId: orderId };

            this.loading = true;
            orderDetail(reqData).then( res => {
                this.loading = false;
                this.orderData = [res.data];
                this.rebookData.bookDate = res.data.depTime;
                this.rebookData.planNo = res.data.flightNo;
                this.passengerData = res.data.passengerList;
            }).catch( err => {
                this.loading = false;
                console.log(err);
            });
        },

        /**
         * 列表选择变化事件
         */
        handleSelectionChange(val) {
            if (!val) return;

            this.choosedPassengeList = [];
            this.rebookData.passengerList = [];
            val.length > 0 && val.forEach( item => {
                this.choosedPassengeList.push({ id: item.id });

                //  如果是改签(type == 3)，处理改签信息交互 
                if ( this.$route.query.type == 3 ) {
                    this.rebookData.passengerList.push({ passengerName: item.name });
                }
            });
        },

        /**
         * 保存修改的订单
         */
        saveEdit() {
            this.$confirm(`是否确认保存本次编辑?`, '提示', {
                confirmButtonText: '确定',
                cancelButtonText: '取消',
                type: 'warning',
            }).then( () => {
                let reqData = this.orderData[0];

                this.loading = true;
                orderEdit(reqData).then( res => {
                    this.$message({ type: 'success', message: '提交编辑成功' });
                    this.$router.go(-1);
                }).catch( err => {
                    this.loading = false;
                    console.log(err);
                });
            }).catch( () => {});
        },

        /**
         * 提交改签信息
         */
        saveRebook() {
            if ( this.choosedPassengeList.length === 0 ) {
                this.$message({ type: 'warning', message: '请至少选择一位乘客' });
                return;
            }

            this.$confirm(`是否确认提交改签申请?`, '提示', {
                confirmButtonText: '确定',
                cancelButtonText: '取消',
                type: 'warning',
            }).then( () => {
                this.submitRebookData();
            }).catch( () => {});
        },

        /**
         * 提交改签信息到后台
         */
        submitRebookData() {
            console.log(this.rebookData);
        },

        /**
         * 提交退票信息
         */
        saveRefund() {
            if ( this.choosedPassengeList.length === 0 ) {
                this.$message({ type: 'warning', message: '请至少选择一位乘客' });
                return;
            }

            if ( !this.refundData.recedeRemark ) {
                this.$message({ type: 'warning', message: '请填写退票说明' });
                return;
            }

            if ( !this.refundData.recedeImg ) {
                this.$message({ type: 'warning', message: '请上传图片' });
                return;
            }

            this.$confirm(`是否确认提交退票申请?`, '提示', {
                confirmButtonText: '确定',
                cancelButtonText: '取消',
                type: 'warning',
            }).then( () => {
                this.submitRefundData();
            }).catch( () => {});
        },

        /**
         * 提交退票申请到后台
         */
        submitRefundData() {
            this.refundData.passengerList = JSON.parse(JSON.stringify(this.choosedPassengeList));

            this.loading = true;
            ticketRefund(this.refundData).then( res => {
                this.loading = false;
                this.$message({ type: 'success', message: res.message });
                this.$router.go(-1);
            }).catch( err => {
                console.log(err);
                this.loading = false;
            });
        },

        /**
         * 确认付款
         */
        confirmPay() {
            sessionStorage.setItem('payData', JSON.stringify(this.orderData[0]));

            this.$router.push({
                path: '/pay/orderdetail',
                query: { orderId: this.$route.query.orderId, svopId: this.$route.query.svopId }
            });
        },

        uploadFile(e) {
            let file = e.file;


            if ( !['image/jpeg', 'image/png'].includes(file.type) ) {
                this.$message({ type: 'error', message: '请上传jpg或png格式图片' });
                this.imageUrl = '';
                return;
            }

            let formData = new FormData();
            // let token = 'true';
            // formData.append('token', token);
            formData.append('file', file);

            this.loading = true;
            axios({
                headers: { 'Content-Type': 'multipart/form-data' },
                method: 'post',
                url: 'http://120.77.203.53:19000/api/purse/upload/picture',
                data: formData
            }).then( res => {
                this.loading = false;
                this.refundData.recedeImg = res.data.data;
            }).catch( err => {});
        },

        onSuccess(file) {
            this.imageUrl = URL.createObjectURL(file.raw);
        }
    },

    // beforeRouteEnter(to, from, next) {
    //     let pageType = to.query.type;
    //     if ( pageType == 2 ) to.meta.title = `${to.meta.title}(退票)`;
    //     else if ( pageType == 3 ) to.meta.title = `${to.meta.title}(改签)`;
    //     else if ( pageType == 5 ) to.meta.title = `${to.meta.title}(付款)`;
    //     else {}
    //     next();
    // },
};
